package ab;

import java.awt.Color;

/**
 * The color scheme for rendering the different address categories within the
 * address table.
 * 
 * @author ahoefer
 * 
 */
public enum ColorScheme {

	/**
	 * Red background, selection background and focus highlight.
	 */
	RED(new Color(255, 206, 199), new Color(233, 159, 150), new Color(163, 111,
			105)),
	/**
	 * Yellow background, selection background and focus highlight.
	 */
	YELLOW(new Color(255, 233, 199), new Color(233, 200, 150), new Color(163,
			140, 105)),

	/**
	 * Blue background, selection background and focus highlight.
	 */
	BLUE(new Color(160, 180, 200), new Color(112, 140, 169), new Color(78, 98,
			118)),

	/**
	 * Green background, selection background and focus highlight.
	 */
	GREEN(new Color(168, 215, 181), new Color(120, 187, 138), new Color(84,
			130, 96));

	private final Color background;

	private final Color selectionBackground;

	private final Color focusHighlight;

	private ColorScheme(Color background, Color selectionBackground,
			Color focusHighlight) {
		this.background = background;
		this.selectionBackground = selectionBackground;
		this.focusHighlight = focusHighlight;
	}

	/**
	 * Gets the background color.
	 * 
	 * @return Never null.
	 */
	public Color getBackground() {
		return background;
	}

	/**
	 * Gets the color for the selection background.
	 * 
	 * @return Never null.
	 */
	public Color getSelectionBackground() {
		return selectionBackground;
	}

	/**
	 * Get the color for the focus highlight.
	 * 
	 * @return Never null.
	 */
	public Color getFocusHighlight() {
		return focusHighlight;
	}
}
