package ab.table;

import java.awt.Dimension;

import javax.swing.JTable;

import ab.Address;
import ab.Category;

/**
 * A table to display the address data.
 * 
 * @author ahoefer
 * 
 */
public class AddressTable extends JTable {

	private static final long serialVersionUID = 1514857297355439104L;

	private AddressTableModel model;

	/**
	 * Creates a new AddressTable.
	 */
	public AddressTable() {
		model = new AddressTableModel();
		setModel(model);
		setPreferredScrollableViewportSize(new Dimension(400, 100));
		setDefaultRenderer(String.class, new AddressTableStringRenderer());
		setDefaultRenderer(Category.class, new AddressTableCategoryRenderer());
		setRowHeight(20);
		setAutoCreateRowSorter(true);
	}

	/**
	 * Returns the table's model.
	 * 
	 * @return the model
	 */
	@Override
	public AddressTableModel getModel() {
		return model;
	}

	/**
	 * Gets the address in the selected row form the model or null if no row was
	 * selected.
	 * 
	 * @return the selected address
	 */
	public Address getSelectedAddress() {
		int index = getSelectedRow();
		if (index <= -1) {
			return null;
		}
		return model.getAddress(index);
	}

	/**
	 * Adds the given address to the model.
	 * 
	 * @param address
	 *            the address to add
	 */
	public void addAddress(Address address) {
		model.addAddress(address);
	}

	/**
	 * Delegates to the table's model to update the address in the selected row
	 * using the content of the specified address. If no address was selected
	 * nothing happens.
	 * 
	 * @param address
	 *            The address containing the current data.
	 */
	public void updateSelectedAddress(Address address) {
		int index = getSelectedRow();
		if (index <= -1) {
			return;
		}
		model.updateAddress(index, address);
	}

	/**
	 * Removes the address in the selected row. If no row was selected nothing
	 * happens.
	 */
	public void removeSelectedAddress() {
		int index = getSelectedRow();
		if (index > -1) {
			model.removeAddress(index);
		}
	}
}
