package ab.table;

import java.awt.Color;
import java.awt.Component;

import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.table.TableCellRenderer;

import ab.Address;
import ab.Category;
import ab.ColorScheme;

/**
 * A TableCellRenderer for rendering all Strings in an AddressTable.
 * 
 * @see AddressTable
 * @author ahoefer
 * 
 */
public class AddressTableStringRenderer implements TableCellRenderer {

	private JLabel label;

	/**
	 * Returns the table cell render for Strings in an AddressTable.
	 * 
	 * @param table
	 *            the JTable
	 * @param value
	 *            the value to assign to the cell at [row, column]
	 * @param isSelected
	 *            true if cell is selected
	 * @param hasFocus
	 *            true if cell has focus
	 * @param row
	 *            the row of the cell to render
	 * @param column
	 *            the column of the cell to render
	 * @return A component whose paint() method will render the specified value.
	 */
	public Component getTableCellRendererComponent(JTable table, Object value,
			boolean isSelected, boolean hasFocus, int row, int column) {
		
		if (label == null) {
			label = new JLabel();
			label.setFont(table.getFont());
			label.setOpaque(true);
		}

		String str = value.toString();
		label.setText(str);
		label.setToolTipText(str);

		int modelRow = table.convertRowIndexToModel(row);
		AddressTableModel model = (AddressTableModel) table.getModel();
		Address address = model.getAddress(modelRow);
		Category category = address.getCategory();
		ColorScheme colorScheme = category.getColorScheme();
		Color bg = isSelected ? colorScheme.getSelectionBackground()
				: colorScheme.getBackground();
		label.setBackground(bg);

		if (hasFocus) {
			label.setBorder(BorderFactory.createLineBorder(colorScheme
					.getFocusHighlight()));
		} else {
			label.setBorder(BorderFactory.createEmptyBorder(1, 1, 1, 1));
		}

		return label;
	}
}
